﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Windows.Threading;

namespace BioBridgeSDK
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        BioBridgeSDKLib.BioBridgeSDKClass sdk = new BioBridgeSDKLib.BioBridgeSDKClass();

        public MainWindow()
        {
            InitializeComponent();

            btnDownload.IsEnabled = false;
            btnConnect.IsEnabled = true;
        }

        private void btnConnect_Click(object sender, RoutedEventArgs e)
        {
            this.Cursor = Cursors.Wait;
            btnConnect.IsEnabled = false;

            if (btnConnect.Content.ToString() == "Connect")
            {
                listBox1.Items.Clear();

                ShowMessage("Start connect device...");
                if (sdk.Connect_TCPIP("", 1, txtIP.Text.Trim(), 4370, 0) == 0)
                {
                    ShowMessage("Successfully connect device...");
                    ShowMessage("");

                    string sdkVer = string.Empty;
                    if (sdk.GetSDKVersion(ref sdkVer, 0) == 0)
                    {
                        ShowMessage("SDK Version: " + sdkVer);
                    }
                    else
                    {
                        ShowMessage("SDK Version Error");
                    }

                    string firmware = string.Empty;
                    if (sdk.GetFirmwareVersion(ref firmware) == 0)
                    {
                        ShowMessage("Firmware Version: " + firmware);
                    }
                    else
                    {
                        ShowMessage("Firmware Error");
                    }

                    int yr = 0;
                    int mth = 0;
                    int day_Renamed = 0;
                    int hr = 0;
                    int min = 0;
                    int sec = 0;
                    if (sdk.GetDeviceTime(ref yr, ref mth, ref day_Renamed, ref hr, ref min, ref sec) == 0)
                    {
                        ShowMessage("Device Date and Time: " + Convert.ToString(day_Renamed) + "/" + Convert.ToString(mth) + "/" + Convert.ToString(yr) + " " + Convert.ToString(hr) + ":" + Convert.ToString(min) + ":" + Convert.ToString(sec));
                    }
                    else
                    {
                        ShowMessage("!Date and Time");
                    }


                    ShowMessage("Manufacturer: " + sdk.VC);
                    ShowMessage("Serial No: " + sdk.SN);
                    ShowMessage("Mac Add: " + sdk.MAC);
                    ShowMessage("Model Name: " + sdk.DC);

                    if (sdk.Finger10 == 1)
                    {
                        ShowMessage("This is a FP10 reader");
                    }
                    else
                    {
                        ShowMessage("This is not a FP10 reader");
                    }

                    int i = 0;
                    if (sdk.GetDeviceStatus(1, ref i) == 0)
                    {
                        ShowMessage("Administrator: " + Convert.ToString(i));
                    }
                    if (sdk.GetDeviceStatus(2, ref i) == 0)
                    {
                        ShowMessage("Users: " + Convert.ToString(i));
                    }
                    if (sdk.GetDeviceStatus(3, ref i) == 0)
                    {
                        ShowMessage("Fingerprints: " + Convert.ToString(i));
                    }
                    if (sdk.GetDeviceStatus(4, ref i) == 0)
                    {
                        ShowMessage("Passwords: " + Convert.ToString(i));
                    }
                    if (sdk.GetDeviceStatus(6, ref i) == 0)
                    {
                        ShowMessage("Logs: " + Convert.ToString(i));
                    }

                    btnDownload.IsEnabled = true;
                    btnConnect.IsEnabled = true;
                    btnConnect.Content = "Disconnect";
                    ShowMessage("");

                }
                else
                {
                    btnDownload.IsEnabled = false;
                    btnConnect.IsEnabled = true;
                    btnConnect.Content = "Connect";
                }
            }
            else
            {
                if (sdk.Disconnect() == 0)
                {
                    ShowMessage("Disconnect from Device");
                }
                else
                {
                    ShowMessage("Unable to disconnect!");
                }

                btnDownload.IsEnabled = false;
                btnConnect.IsEnabled = true;
                btnConnect.Content = "Connect";
                ShowMessage("");
            }

            this.Cursor = Cursors.Arrow;
        }

        protected void ShowMessage(string msg)
        {
            listBox1.Items.Add(msg);
            listBox1.SelectedIndex = listBox1.Items.Count - 1;
            listBox1.ScrollIntoView(listBox1.Items[listBox1.Items.Count - 1]);
             
            DoEvents();
        }

        public static void DoEvents()// process messsages
        {
            Application.Current.Dispatcher.Invoke(DispatcherPriority.Background, new Action(delegate { }));
        }

        private void btnDownload_Click(object sender, RoutedEventArgs e)
        {
            if (sdk.IsTFT() == 0)
            {
                string enrollNo = "";
                int yr = 0;
                int mth = 0;
                int day_Renamed = 0;
                int hr = 0;
                int min = 0;
                int sec = 0;
                int ver = 0;
                int io = 0;
                int work = 0;
                int iSize = 0;

                if (sdk.ReadGeneralLog(ref iSize) == 0)
                {
                    do
                    {
                        ShowMessage(("No: " + enrollNo + " Date: " + Convert.ToString(day_Renamed) + "/" + Convert.ToString(mth) + "/" + Convert.ToString(yr) + " Time: " + Convert.ToString(hr) + ":" + Convert.ToString(min) + ":" + Convert.ToString(sec) + " Verify: " + Convert.ToString(ver) + " I/O: " + Convert.ToString(io) + " Work Code: " + Convert.ToString(work)));
                    } while (sdk.SSR_GetGeneralLog(ref enrollNo, ref yr, ref mth, ref day_Renamed, ref hr, ref min, ref sec, ref ver, ref io, ref work) == 0);
                }
            }
            else
            {
                int yr = 0;
                int mth = 0;
                int day_Renamed = 0;
                int hr = 0;
                int min = 0;
                int sec = 0;

                int enrollNo = 0;
                int ver = 0;
                int io = 0;
                int work = 0;
                int log = 0;

                if (sdk.ReadGeneralLog(ref log) == 0)
                {
                    do
                    {
                        ShowMessage(("No: " + Convert.ToString(enrollNo) + " Date:" + Convert.ToString(day_Renamed) + "/" + Convert.ToString(mth) + "/" + Convert.ToString(yr) + " Time: " + Convert.ToString(hr) + ":" + Convert.ToString(min) + ":" + Convert.ToString(sec) + " Verify: " + Convert.ToString(ver) + " I/O: " + Convert.ToString(io) + " Work Code: " + Convert.ToString(work)));
                    } while (sdk.GetGeneralLog(ref enrollNo, ref yr, ref mth, ref day_Renamed, ref hr, ref min, ref sec, ref ver, ref io, ref work) == 0);
                }
                else
                {
                    ShowMessage(("Unable to Read General Log!!"));
                }

            }
        }
    }
}
